@@ -1,4 +1,3 @@
-from email.policy import default
 import io
 import click
 import sys
@@ -11,7 +10,9 @@ from .core import ThriftData, ThriftFormatter
 @click.argument('fout', type=click.Path(file_okay=True, writable=True), required=False)
 def main(fout=None, fin=None):
     data = ThriftData.from_file(fin)
-    fmt = ThriftFormatter(data.document)
+    fmt = ThriftFormatter(data)
+    fmt.patch()
+
     if fout is None:
         fmt.format(sys.stdout)
     else:
